@@ -4,13 +4,10 @@ use std::fmt::{Display, Formatter};
 
 #[derive(Debug, Serialize, Deserialize)]
 pub enum Priority {
-    Emergency,
-    Alert,
     Critical,
     Error,
     Warning,
-    Notice,
-    Informational,
+    Info,
     Debug,
     Trace,
     None,
@@ -19,13 +16,10 @@ pub enum Priority {
 impl Display for Priority {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         match self {
-            Self::Emergency => write!(f, "Emergency"),
-            Self::Alert => write!(f, "Alert"),
             Self::Critical => write!(f, "Critical"),
             Self::Error => write!(f, "Error"),
             Self::Warning => write!(f, "Warning"),
-            Self::Notice => write!(f, "Notice"),
-            Self::Informational => write!(f, "Informational"),
+            Self::Info => write!(f, "Info"),
             Self::Debug => write!(f, "Debug"),
             Self::Trace => write!(f, "Trace"),
             Self::None => write!(f, "None"),
